FunctionAuthClient class

Constructors

FunctionAuthClient(int fllId, String userField)

Properties

fllId int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userField String
getter/setter pair

Methods

login(String userName, String password) Future<FunctionUser>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited