Instance class

Inheritance

Constructors

Instance({required int fllId, required int id, required int parentId, InstanceIdentity? parent, required Map<String, dynamic> fields, String title = ""})
const
Instance.fromJson(Map<String, dynamic> json)
factory

Properties

fields Map<String, dynamic>
final
fllId int
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id int
finalinherited
parent InstanceIdentity?
final
parentId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited