InstanceQuery class

Constructors

InstanceQuery(int fllId)

Properties

fllId int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

filter(String field, String value) InstanceQuery
get() Future<List<Instance>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withParentId(int parentId) InstanceQuery

Operators

operator ==(Object other) bool
The equality operator.
inherited