Musketeer class

Constructors

Musketeer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

uri Uri
no setter

Static Methods

get(String uri) Future<String>
getBearerToken() String
getHeaders() Map<String, String>
getUri(String path) Uri
init(String baseUrl, String clientId, String apiKey) → void
post(String uri, Object body) Future<String>
SetUserName(String value) → void