User class

Constructors

User.fromJson(Map<String, dynamic> json)

Properties

community Community
final
communityDescription String
final
communityId int
final
emailAddress String
final
firstName String
final
fllId int
final
hashCode int
The hash code for this object.
no setterinherited
instanceId int
final
roles List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
superUser bool
final
surname String
final
token String
final
userDetails String
final
userId int
final
userName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited