CommunityNode class abstract
- Implementers
Constructors
-
CommunityNode(int id, String description, List<
CommunityNode> items)
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
-
items
→ List<
CommunityNode> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
dynamic index) → dynamic
Static Methods
-
fromJson(
Map< String, dynamic> json) → CommunityNode